// 1. Track and save last 50 search keywords
function track_recent_search_queries() {
    if (is_search() && !is_admin()) {
        $search_term = trim(get_search_query());

        if (!empty($search_term)) {
            $recent_searches = get_option('recent_search_terms', []);

            // Add new search term
            $recent_searches[] = $search_term;

            // Limit to last 50
            if (count($recent_searches) > 50) {
                $recent_searches = array_slice($recent_searches, -50);
            }

            update_option('recent_search_terms', $recent_searches);
        }
    }
}
add_action('template_redirect', 'track_recent_search_queries');


// 2. Create Dashboard Widget with title
function recent_search_terms_dashboard_widget() {
    wp_add_dashboard_widget(
        'recent_search_terms_widget',             // Widget slug
        '50 Recent Searches Keywords',            // ✅ Title
        'display_recent_search_terms'             // Display callback
    );
}
add_action('wp_dashboard_setup', 'recent_search_terms_dashboard_widget');


// 3. Display the recent 50 keywords + Clear link
function display_recent_search_terms() {
    $recent_searches = get_option('recent_search_terms', []);
    $clear_url = esc_url( add_query_arg('clear_recent_searches', '1', admin_url()) );

    echo '<p><a href="' . $clear_url . '" style="color:red; font-weight:bold;">🧹 Clear Recent Searches</a></p>';

    if (!empty($recent_searches)) {
        $recent_searches = array_reverse($recent_searches); // Show newest first

        echo '<ol>';
        foreach ($recent_searches as $term) {
            echo '<li>' . esc_html($term) . '</li>';
        }
        echo '</ol>';
    } else {
        echo '<p>No recent search keywords found.</p>';
    }
}


// 4. Admin-only URL to clear the saved search keywords
add_action('admin_init', function() {
    if (isset($_GET['clear_recent_searches']) && current_user_can('manage_options')) {
        delete_option('recent_search_terms');
        wp_redirect(remove_query_arg('clear_recent_searches'));
        exit;
    }
});
